#
# spec file for package buildstream
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define real_name BuildStream
Name:           buildstream
Version:        1.1.2
Release:        bp155.2.13
Summary:        A framework for modelling build pipelines in YAML
License:        LGPL-2.1-or-later
Group:          Development/Tools/Building
URL:            https://wiki.gnome.org/Projects/BuildStream
Source:         https://download.gnome.org/sources/BuildStream/1.1/%{real_name}-%{version}.tar.xz
BuildRequires:  bubblewrap
BuildRequires:  fdupes
BuildRequires:  python3-base >= 3.4
BuildRequires:  python3-devel >= 3.4
BuildRequires:  python3-gobject
BuildRequires:  python3-pytest-runner
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
BuildRequires:  typelib-1_0-OSTree-1_0
Requires:       bubblewrap
Requires:       python3-base >= 3.4
Requires:       python3-gobject
Requires:       python3-psutil
Requires:       python3-ruamel.yaml
Requires:       typelib-1_0-OSTree-1_0

%description
BuildStream is a flexible and extensible framework for the modelling of
build and CI pipelines in a declarative YAML format, written in python.

%prep
%setup -q -n %{real_name}-%{version}
# Fix the shebang
find -type f -exec sed -i 's|%{_bindir}/env python3|%{_bindir}/python3|' {} \;

%build
%python3_build

%install
%python3_install
# Remove unneeded tests
rm -rf %{buildroot}%{python3_sitelib}/tests
%fdupes %{buildroot}%{python3_sitelib}

%files
%license COPYING
%doc HACKING.rst MAINTAINERS NEWS README.rst
%{_bindir}/bst
%{_bindir}/bst-artifact-receive
%{_datadir}/bash-completion/completions/bst
%{python3_sitelib}/BuildStream-*-py3.?.egg-info
%{python3_sitelib}/buildstream
%{_mandir}/man1/bst*%{ext_man}

%changelog
* Mon Mar 26 2018 luc14n0@linuxmail.org
- Update to version 1.1.2:
  + New ref-storage option allows one to store source refs, such as
    git shas, in one central project.refs file instead of inline
    with the source declarations.
  + Deprecated `--track-save` optionality in `bst build`, this does
    not make sense to support now that there is project.refs.
  + Added the `sandbox` configuration option which can be used in
    `project.conf` and elements, to control the user ID and group
    ID used in build sandboxes.
  + Added new `deb` source implementation, for staging of
    downloaded deb package files.
* Thu Mar  8 2018 dimstar@opensuse.org
- Update to version 1.1.1:
  + New project configuration controlling how the sandbox behaves
    when `bst shell` is used; allowing projects to provide a more
    functional shell environment.
  + The `bst shell` command now has a `--mount` option allowing
    users to mount files and directories into the sandbox for
    testing purposes.
  + Log lines are now configurable with the new "message-format"
    user configuration, allowing one to express optional fields
    such as microsecond precision and wallclock time.
  + Newly added filter element
  + Git source plugin now allows disabling of submodule checkouts
  + In the same way we allow overriding element configurations
    by their 'kind' in project.conf, we now support the same
    for source plugin configurations.
  + Tar and zip sources now automatically recall an `etag`
    from the http headers, optimizing tracking of tarballs
    significantly (glgo#GNOME/BuildStream#62).
* Wed Feb 28 2018 luc14n0@linuxmail.org
- Update to version 1.1.0:
  + Multiple artifact caches are now supported in project and
    user configuration with a priority order
    (gl#BuildStream/buildstream#85).
  + Add junction support for subprojects.
  + Changes towards incremental builds in workspaces.
  + `bst shell --build` now creates true build sandbox.
  + Many bug fixes.
* Fri Jan  5 2018 luc14n0@linuxmail.org
- Initial openSUSE package, version 1.0.1.
